@@ -1,8 +1,8 @@
 /*****************************************************************************
  * callback.c : Callbacks for CD digital audio input module
  *****************************************************************************
- * Copyright (C) 2004 VideoLAN
- * $Id: callback.c 8606 2004-08-31 18:32:54Z rocky $
+ * Copyright (C) 2004 the VideoLAN team
+ * $Id$
  *
  * Authors: Rocky Bernstein <rocky@panix.com>
  *
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 #include "callback.h"
@@ -34,9 +34,9 @@ CDDADebugCB   ( vlc_object_t *p_this, const char *psz_name,
 
     p_cdda = (cdda_data_t *)p_cdda_input->p_sys;
 
-    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT)) 
+    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, "Old debug (x%0x) %d, new debug (x%0x) %d",
+        msg_Dbg( p_cdda_input, "old debug (x%0x) %d, new debug (x%0x) %d",
                  p_cdda->i_debug, p_cdda->i_debug, val.i_int, val.i_int);
     }
     p_cdda->i_debug = val.i_int;
@@ -56,9 +56,9 @@ CDDBEnabledCB   ( vlc_object_t *p_this, const char *psz_name,
     p_cdda = (cdda_data_t *)p_cdda_input->p_sys;
 
 #ifdef HAVE_LIBCDDB
-    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT)) 
+    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, "Old CDDB Enabled (x%0x) %d, new (x%0x) %d",
+        msg_Dbg( p_cdda_input, "old CDDB Enabled (x%0x) %d, new (x%0x) %d",
                  p_cdda->b_cddb_enabled, p_cdda->b_cddb_enabled,
                  val.b_bool, val.b_bool);
     }
@@ -79,10 +79,10 @@ CDTextEnabledCB   ( vlc_object_t *p_this, const char *psz_name,
 
     if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, "Old CDText Enabled %d, new %d",
-                 p_cdda->b_cdtext_enabled, val.b_bool);
+        msg_Dbg( p_cdda_input, "old CDText Enabled %d, new %d",
+                 p_cdda->b_cdtext, val.b_bool);
     }
-    p_cdda->b_cdtext_enabled = val.b_bool;
+    p_cdda->b_cdtext = val.b_bool;
     return VLC_SUCCESS;
 }
 
@@ -98,8 +98,8 @@ CDDANavModeCB( vlc_object_t *p_this, const char *psz_name,
 
     if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, 
-		 "Old Navigation Mode Enabled %d, new %d",
+        msg_Dbg( p_cdda_input,
+         "old Navigation Mode Enabled %d, new %d",
                  p_cdda->b_nav_mode, val.b_bool);
     }
     p_cdda->b_nav_mode = val.b_bool;
@@ -117,9 +117,9 @@ CDTextPreferCB   ( vlc_object_t *p_this, const char *psz_name,
     p_cdda = (cdda_data_t *)p_cdda_input->p_sys;
 
 #ifdef HAVE_LIBCDDB
-    if ( p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT)) 
+    if ( p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, "Old CDText Prefer (x%0x) %d, new (x%0x) %d",
+        msg_Dbg( p_cdda_input, "old CDText Prefer (x%0x) %d, new (x%0x) %d",
                  p_cdda->b_cdtext_prefer, p_cdda->b_cdtext_prefer,
                  val.b_bool, val.b_bool);
     }
@@ -138,9 +138,9 @@ CDDABlocksPerReadCB ( vlc_object_t *p_this, const char *psz_name,
 
     p_cdda = (cdda_data_t *)p_cdda_input->p_sys;
 
-    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT)) 
+    if (p_cdda->i_debug & (INPUT_DBG_CALL|INPUT_DBG_EXT))
     {
-        msg_Dbg( p_cdda_input, "Old blocks per read: %d, new %d",
+        msg_Dbg( p_cdda_input, "old blocks per read: %d, new %d",
                  p_cdda->i_blocks_per_read, val.i_int);
     }
 
@@ -150,7 +150,7 @@ CDDABlocksPerReadCB ( vlc_object_t *p_this, const char *psz_name,
     else
     {
         msg_Warn( p_cdda_input,
-             "Number of blocks (%d) has to be between %d and %d. No change.",
+             "number of blocks (%d) has to be between %d and %d. No change.",
               val.i_int, MIN_BLOCKS_PER_READ, MAX_BLOCKS_PER_READ );
     }
     return VLC_SUCCESS;
