@@ -2,7 +2,7 @@
  * dvdnav.c: DVD module using the dvdnav library.
  *****************************************************************************
  * Copyright (C) 2004 the VideoLAN team
- * $Id: 6538f94379598c91501822641bcda77bf6e800be $
+ * $Id: 9c4677044631e76949f3215e11403e37eedee506 $
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -1434,7 +1434,7 @@ static int ProbeDVD( demux_t *p_demux, char *psz_name )
         return VLC_SUCCESS;
     }
 
-    if( stat( psz_name, &stat_info ) || !S_ISREG( stat_info.st_mode ) )
+    if( utf8_stat( psz_name, &stat_info ) || !S_ISREG( stat_info.st_mode ) )
     {
         /* Let dvdnav_open() do the probing */
         return VLC_SUCCESS;
