@@ -2,7 +2,7 @@
  * mmsh.h:
  *****************************************************************************
  * Copyright (C) 2001, 2002 the VideoLAN team
- * $Id: mmsh.h 11664 2005-07-09 06:17:09Z courmisch $
+ * $Id$
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *
@@ -18,9 +18,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
+#ifndef _MMSH_H_
+#define _MMSH_H_ 1
+
 typedef struct
 {
     uint16_t i_type;
@@ -44,11 +47,14 @@ struct access_sys_t
     int             fd;
     vlc_url_t       url;
 
+    bool      b_proxy;
+    vlc_url_t       proxy;
+
     int             i_request_context;
 
     uint8_t         buffer[BUFFER_SIZE + 1];
 
-    vlc_bool_t      b_broadcast;
+    bool      b_broadcast;
 
     uint8_t         *p_header;
     int             i_header;
@@ -63,3 +69,5 @@ struct access_sys_t
     asf_header_t    asfh;
     guid_t          guid;
 };
+
+#endif
