@@ -1,11 +1,11 @@
 /*****************************************************************************
  * fspanel.m: MacOS X full screen panel
  *****************************************************************************
- * Copyright (C) 2006-2007 the VideoLAN team
- * $Id: fspanel.m 17038 2006-10-12 18:24:34Z fkuehne $
+ * Copyright (C) 2006-2008 the VideoLAN team
+ * $Id: d3ceab14d3df584771270492ab28288ac5e5e3ad $
  *
  * Authors: Jérôme Decoodt <djc at videolan dot org>
- *          Felix Kühne <fkuehne at videolan dot org>
+ *          Felix Paul Kühne <fkuehne at videolan dot org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,12 @@
 #import "intf.h"
 #import "controls.h"
 #import "vout.h"
+#import "misc.h"
 #import "fspanel.h"
 
-#define KEEP_VISIBLE_AFTER_ACTION 4 /* time in half-sec until this panel will hide again after an user's action */
+@interface VLCFSPanel ()
+- (void)hideMouse;
+@end
 
 /*****************************************************************************
  * VLCFSPanel
@@ -48,11 +51,11 @@
     [win setBackgroundColor:[NSColor clearColor]];
     
     /* let the window sit on top of everything else and start out completely transparent */
-    [win setLevel:NSFloatingWindowLevel];
-    [win setAlphaValue:0.0];
+    [win setLevel:NSModalPanelWindowLevel];
     i_device = 0;
-
     [win center];
+    hideAgainTimer = fadeTimer = nil;
+    [self setNonActive:nil];
     return win;
 }
 
@@ -95,9 +98,12 @@
 -(void)dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
+
     if( hideAgainTimer )
+    {
+        [hideAgainTimer invalidate];
         [hideAgainTimer release];
+    }
     [self setFadeTimer:nil];
     [super dealloc];
 }
@@ -108,13 +114,18 @@
     NSPoint theCoordinate;
     NSRect theScreensFrame;
     NSRect theWindowsFrame;
-
-    if( i_device < 0 || i_device >= (signed int)[[NSScreen screens] count] )
+    NSScreen *screen;
+    
+    /* user-defined screen */
+    screen = [NSScreen screenWithDisplayID: (CGDirectDisplayID)i_device];
+    
+    if (!screen)
+    {
         /* invalid preferences or none specified, using main screen */
-        theScreensFrame = [[NSScreen mainScreen] frame];
-    else
-        /* user-defined screen */
-        theScreensFrame = [[[NSScreen screens] objectAtIndex: i_device] frame];
+        screen = [NSScreen mainScreen];
+    }
+
+    theScreensFrame = [screen frame];
 
     theWindowsFrame = [self frame];
     
@@ -206,14 +217,13 @@
     {
         b_keptVisible = NO;
         b_fadeQueued = NO;
-        [[self fadeTimer] release];
         [self setFadeTimer: NULL];
         [self fadeIn];
         return;
     }
     if( [self alphaValue] > 0.0 )
-        [self setAlphaValue:[self alphaValue]-0.1];
-    if( [self alphaValue] <= 0.1 )
+        [self setAlphaValue:[self alphaValue]-0.05];
+    if( [self alphaValue] <= 0.05 )
     {
         b_displayed = NO;
         [self setAlphaValue:0.0];
@@ -238,12 +248,25 @@
         [[[[[VLCMain sharedInstance] getControls] getVoutView] window] makeKeyWindow];
 }
 
+- (void)hideMouse
+{
+    [NSCursor setHiddenUntilMouseMoves: YES];
+}
+
 - (void)fadeIn
 {
-    /* in case that the user don't want us to appear, just return here */
-    if(! config_GetInt( VLCIntf, "macosx-fspanel" ) || b_nonActive )
+    /* in case that the user don't want us to appear, make sure we hide the mouse */
+
+    if( !config_GetInt( VLCIntf, "macosx-fspanel" ) )
+    {
+        float time = (float)var_CreateGetInteger( VLCIntf, "mouse-hide-timeout" ) / 1000.;
+        [self setFadeTimer:[NSTimer scheduledTimerWithTimeInterval:time target:self selector:@selector(hideMouse) userInfo:nil repeats:NO]];
         return;
-    
+    }
+
+    if( b_nonActive )
+        return;
+
     [self orderFront: nil];
     
     if( [self alphaValue] < 1.0 || b_displayed != YES )
@@ -264,7 +287,7 @@
     if( ( [self alphaValue] > 0.0 ) )
     {
         if (![self fadeTimer])
-            [self setFadeTimer:[NSTimer scheduledTimerWithTimeInterval:0.1 target:self selector:@selector(unfocus:) userInfo:[NSNumber numberWithShort:0] repeats:YES]];
+            [self setFadeTimer:[NSTimer scheduledTimerWithTimeInterval:0.05 target:self selector:@selector(unfocus:) userInfo:[NSNumber numberWithShort:0] repeats:YES]];
         else if ([[[self fadeTimer] userInfo] shortValue]==1)
             b_fadeQueued=YES;
     }
@@ -279,13 +302,18 @@
     /* get us a valid timer */
     if(! b_alreadyCounting )
     {
-        hideAgainTimer = [NSTimer scheduledTimerWithTimeInterval: 0.5
+        i_timeToKeepVisibleInSec = var_CreateGetInteger( VLCIntf, "mouse-hide-timeout" ) / 500;
+        if( hideAgainTimer )
+        {
+            [hideAgainTimer invalidate];
+            [hideAgainTimer autorelease];
+        }
+        /* released in -autoHide and -dealloc */
+        hideAgainTimer = [[NSTimer scheduledTimerWithTimeInterval: 0.5
                                                           target: self 
                                                         selector: @selector(keepVisible:)
                                                         userInfo: nil 
-                                                         repeats: YES];
-        [hideAgainTimer fire];
-        [hideAgainTimer retain];
+                                                         repeats: YES] retain];
         b_alreadyCounting = YES;
     }
 }
@@ -294,20 +322,15 @@
 {
     /* if the user triggered an action, start over again */
     if( b_keptVisible )
-    {
-        i_timeToKeepVisibleInSec = KEEP_VISIBLE_AFTER_ACTION;
         b_keptVisible = NO;
-    }
-    
+
     /* count down until we hide ourselfes again and do so if necessary */
-    i_timeToKeepVisibleInSec -= 1;
-    if( i_timeToKeepVisibleInSec < 1 )
+    if( --i_timeToKeepVisibleInSec < 1 )
     {
+        [self hideMouse];
         [self fadeOut];
-        [timer invalidate];
-        [timer release];
+        [hideAgainTimer invalidate]; /* released in -autoHide and -dealloc */
         b_alreadyCounting = NO;
-        timer = NULL;
     }
 }
 
@@ -321,7 +344,7 @@
 {
     [timer retain];
     [fadeTimer invalidate];
-    [fadeTimer release];
+    [fadeTimer autorelease];
     fadeTimer=timer;
 }
 
@@ -549,7 +572,7 @@
 
 - (void)drawRect:(NSRect)rect
 {
-	NSRect frame = [self frame];
+    NSRect frame = [self frame];
     NSRect image_rect;
     NSImage *img;
     addImage( @"fs_background", 0, 0, NSCompositeCopy, 0 );
@@ -625,4 +648,5 @@
     [self drawKnobInRect: knobRect];
 }
 
-@end
\ No newline at end of file
+@end
+
