@@ -1,8 +1,8 @@
 /*****************************************************************************
  * vout.h: MacOS X interface module
  *****************************************************************************
- * Copyright (C) 2001-2006 the VideoLAN team
- * $Id: vout.h 15096 2006-04-04 20:41:44Z fkuehne $
+ * Copyright (C) 2001-2007 the VideoLAN team
+ * $Id: 314fba02de4bcdeafc22c5d3529c96cbf7000226 $
  *
  * Authors: Colin Delacroix <colin@zoy.org>
  *          Florian G. Pflug <fgp@phlo.org>
@@ -14,7 +14,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,6 +25,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
+#import "misc.h"
 /*****************************************************************************
  * VLCEmbeddedList interface
  *****************************************************************************/
@@ -44,12 +45,17 @@
 /*****************************************************************************
  * VLCVoutView interface
  *****************************************************************************/
+@protocol VLCVoutViewResetting
++ (void)resetVout: (vout_thread_t *)p_vout;
+@end
+
 @interface VLCVoutView : NSView
 {
     vout_thread_t * p_vout;
-    NSView        * o_view;
     NSRect        * s_frame;
 
+    NSView <VLCVoutViewResetting> * o_view;
+
     vout_thread_t * p_real_vout;
     id              o_window;
 }
@@ -58,7 +64,7 @@
 - (void)closeVout;
 - (void)updateTitle;
 - (void)manage;
-- (void)scaleWindowWithFactor: (float)factor;
+- (void)scaleWindowWithFactor: (float)factor animate: (BOOL)animate;
 - (void)setOnTop:(BOOL)b_on_top;
 - (void)toggleFloatOnTop;
 - (void)toggleFullscreen;
@@ -67,9 +73,11 @@
 - (id)getWindow;
 
 + (id)getVoutView: (vout_thread_t *)p_vout subView: (NSView *) view
-                            frame: (NSRect *) s_frame;
+            frame: (NSRect *) s_frame;
 + (vout_thread_t *)getRealVout: (vout_thread_t *)p_vout;
 
+- (void)enterFullscreen;
+- (void)leaveFullscreen;
 @end
 
 /*****************************************************************************
@@ -92,6 +100,7 @@
 @interface VLCEmbeddedVoutView : VLCVoutView
 {
     BOOL b_used;
+    id o_embeddedwindow;
 }
 
 - (void)setUsed: (BOOL)b_new_used;
@@ -100,38 +109,23 @@
 @end
 
 /*****************************************************************************
- * VLCDetachedEmbeddedView interface
+ * VLCVoutWindow interface
  *****************************************************************************/
-
-@interface VLCDetachedEmbeddedVoutView : VLCEmbeddedVoutView
-{
-}
-
-@end
-
-/*****************************************************************************
- * VLCWindow interface
- *****************************************************************************/
-@interface VLCWindow : NSWindow
+@interface VLCVoutWindow : VLCWindow
 {
     vout_thread_t * p_vout;
     VLCVoutView   * o_view;
     NSRect        * s_frame;
 
-    vout_thread_t * p_real_vout;
-    Ptr             p_fullscreen_state;
-    vlc_bool_t      b_init_ok;
-    vlc_bool_t      b_black;
+    bool      b_init_ok;
+    BOOL      fullscreen;
+    NSRect    initialFrame;
 }
 
 - (id) initWithVout: (vout_thread_t *) p_vout view: (VLCVoutView *) view
                      frame: (NSRect *) s_frame;
-- (id)initReal: (id) sender;
-- (void)close;
-- (void)closeWindow;
-- (id)closeReal: (id) sender;
+- (id)initMainThread: (id) sender;
+- (void)leaveFullscreen;
+- (void)enterFullscreen;
 - (id)getVoutView;
-
-- (BOOL)windowShouldClose:(id)sender;
-
 @end
