@@ -2,7 +2,7 @@
  * vlm.cpp : VLM Management
  ****************************************************************************
  * Copyright © 2008 the VideoLAN team
- * $Id$
+ * $Id: 5b4724d58b7a983eec0171c5f801d0f798fe3825 $
  *
  * Authors: Jean-Baptiste Kempf <jb@videolan.org>
  *          Jean-François Massol <jf.massol -at- gmail.com>
@@ -53,7 +53,6 @@
 #include <QScrollArea>
 #include <QFileDialog>
 
-static const char *psz_type[] = { "Broadcast", "Schedule", "VOD" };
 
 VLMDialog *VLMDialog::instance = NULL;
 
@@ -73,9 +72,9 @@ VLMDialog::VLMDialog( QWidget *parent, intf_thread_t *_p_intf ) : QVLCDialog( pa
     ui.saveButton->hide();
 
 #define ADDMEDIATYPES( str, type ) ui.mediaType->addItem( qtr( str ), QVariant( type ) );
-    ADDMEDIATYPES( "Broadcast", QVLM_Broadcast );
-    ADDMEDIATYPES( "Schedule", QVLM_Schedule );
-    ADDMEDIATYPES( "Video On Demand ( VOD )", QVLM_VOD );
+    ADDMEDIATYPES( N_("Broadcast"), QVLM_Broadcast );
+    ADDMEDIATYPES( N_("Schedule"), QVLM_Schedule );
+    ADDMEDIATYPES( N_("Video On Demand ( VOD )"), QVLM_VOD );
 #undef ADDMEDIATYPES
 
     /* Schedule Stuffs */
@@ -526,17 +525,17 @@ VLMBroadcast::VLMBroadcast( QString _name, QString _input, QString _output,
                           : VLMAWidget( _name, _input, _output,
                                         _enabled, _parent, QVLM_Broadcast )
 {
-    nameLabel->setText( "Broadcast: " + name );
+    nameLabel->setText( qtr("Broadcast: ") + name );
     type = QVLM_Broadcast;
     b_looped = _looped;
 
     playButton = new QToolButton;
-    playButton->setIcon( QIcon( QPixmap( ":/play_16px" ) ) );
+    playButton->setIcon( QIcon( QPixmap( ":/play" ) ) );
     objLayout->addWidget( playButton, 1, 0 );
     b_playing = true;
 
     QToolButton *stopButton = new QToolButton;
-    stopButton->setIcon( QIcon( QPixmap( ":/stop_16px" ) ) );
+    stopButton->setIcon( QIcon( QPixmap( ":/stop_b" ) ) );
     objLayout->addWidget( stopButton, 1, 1 );
 
     loopButton = new QToolButton;
@@ -594,7 +593,7 @@ VLMSchedule::VLMSchedule( QString name, QString input, QString output,
                           bool enabled, VLMDialog *parent )
             : VLMAWidget( name, input, output, enabled, parent, QVLM_Schedule )
 {
-    nameLabel->setText( "Schedule: " + name );
+    nameLabel->setText( qtr("Schedule: ") + name );
     schetime = _schetime;
     schedate = _schedate;
     rNumber = _scherepeatnumber;
@@ -616,7 +615,7 @@ VLMVod::VLMVod( QString name, QString input, QString output,
                 bool enabled, QString _mux, VLMDialog *parent)
        : VLMAWidget( name, input, output, enabled, parent, QVLM_VOD )
 {
-    nameLabel->setText( "VOD:" + name );
+    nameLabel->setText( qtr("VOD: ") + name );
 
     mux = _mux;
     muxLabel = new QLabel;
