@@ -1,11 +1,11 @@
 /*****************************************************************************
  * evt_key.hpp
  *****************************************************************************
- * Copyright (C) 2003 VideoLAN
- * $Id: evt_key.hpp 9641 2004-12-22 13:06:43Z gbazin $
+ * Copyright (C) 2003 the VideoLAN team
+ * $Id$
  *
  * Authors: Cyril Deguet     <asmax@via.ecp.fr>
- *          Olivier Teulire <ipkiss@via.ecp.fr>
+ *          Olivier Teulière <ipkiss@via.ecp.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 #ifndef EVT_KEY_HPP
@@ -32,11 +32,11 @@
 class EvtKey: public EvtInput
 {
     public:
-        typedef enum
+        enum ActionType_t
         {
             kDown,
             kUp
-        } ActionType_t;
+        };
 
         EvtKey( intf_thread_t *pIntf, int key, ActionType_t action,
                 int mod = kModNone ):
