@@ -2,7 +2,7 @@
  * taglib.cpp: Taglib tag parser/writer
  *****************************************************************************
  * Copyright (C) 2003-2006 the VideoLAN team
- * $Id: b125966f58cbe08e6eaf15437c982f2770534890 $
+ * $Id$
  *
  * Authors: Clément Stenac <zorglub@videolan.org>
  *          Rafaël Carré <funman@videolanorg>
@@ -409,7 +409,8 @@ vlc_meta_Set##bar( p_meta, p_t->toString().toCString(true))
         }
     }
 
-#define SET( foo, bar ) vlc_meta_Set##foo( p_meta, p_tag->bar ().toCString(true))
+#define SET( foo, bar ) if( !p_tag->bar ().isNull() && !p_tag->bar ().isEmpty() ) \
+        vlc_meta_Set##foo( p_meta, p_tag->bar ().toCString(true))
 #define SETINT( foo, bar ) { \
         char psz_tmp[10]; \
         snprintf( (char*)psz_tmp, 10, "%d", p_tag->bar() ); \
