@@ -2,8 +2,8 @@
  * ps.c: MPEG PS (ISO/IEC 13818-1) / MPEG SYSTEM (ISO/IEC 1172-1)
  *       multiplexer module for vlc
  *****************************************************************************
- * Copyright (C) 2001, 2002 VideoLAN
- * $Id: ps.c 10383 2005-03-18 01:59:44Z markfm $
+ * Copyright (C) 2001, 2002 the VideoLAN team
+ * $Id$
  *
  * Authors: Laurent Aimar <fenrir@via.ecp.fr>
  *          Eric Petit <titer@videolan.org>
@@ -21,40 +21,48 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
-#include <stdlib.h>
 
-#include <vlc/vlc.h>
-#include <vlc/input.h>
-#include <vlc/sout.h>
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc_common.h>
+#include <vlc_plugin.h>
+#include <vlc_sout.h>
+#include <vlc_codecs.h>
+#include <vlc_block.h>
 
-#include "codecs.h"
 #include "bits.h"
 #include "pes.h"
 
-#include "iso_lang.h"
+#include <vlc_iso_lang.h>
 
 /*****************************************************************************
  * Module descriptor
  *****************************************************************************/
 #define DTS_TEXT N_("DTS delay (ms)")
-#define DTS_LONGTEXT N_("This option will delay the DTS (decoding time " \
+#define DTS_LONGTEXT N_("Delay the DTS (decoding time " \
   "stamps) and PTS (presentation timestamps) of the data in the " \
   "stream, compared to the SCRs. This allows for some buffering inside " \
   "the client decoder.")
 
+#define PES_SIZE_TEXT N_("PES maximum size")
+#define PES_SIZE_LONGTEXT N_("Set the maximum allowed PES "\
+  "size when producing the MPEG PS streams.")
+
 static int     Open   ( vlc_object_t * );
 static void    Close  ( vlc_object_t * );
 
 #define SOUT_CFG_PREFIX "sout-ps-"
 
 vlc_module_begin();
-    set_description( _("PS muxer") );
+    set_description( N_("PS muxer") );
     set_shortname( "MPEG-PS" );
     set_category( CAT_SOUT );
     set_subcategory( SUBCAT_SOUT_MUX );
@@ -65,7 +73,9 @@ vlc_module_begin();
     set_callbacks( Open, Close );
 
     add_integer( SOUT_CFG_PREFIX "dts-delay", 200, NULL, DTS_TEXT,
-                 DTS_LONGTEXT, VLC_TRUE );
+                 DTS_LONGTEXT, true );
+    add_integer( SOUT_CFG_PREFIX "pes-max-size", PES_PAYLOAD_SIZE_MAX, NULL,
+                 PES_SIZE_TEXT, PES_SIZE_LONGTEXT, true );
 vlc_module_end();
 
 /*****************************************************************************
@@ -85,9 +95,9 @@ static void MuxWritePackHeader  ( sout_mux_t *, block_t **, mtime_t );
 static void MuxWriteSystemHeader( sout_mux_t *, block_t **, mtime_t );
 static void MuxWritePSM         ( sout_mux_t *, block_t **, mtime_t );
 
-static void StreamIdInit        ( vlc_bool_t *id, int i_range );
-static int  StreamIdGet         ( vlc_bool_t *id, int i_id_min, int i_id_max );
-static void StreamIdRelease     ( vlc_bool_t *id, int i_id_min, int i_id );
+static void StreamIdInit        ( bool *id, int i_range );
+static int  StreamIdGet         ( bool *id, int i_id_min, int i_id_max );
+static void StreamIdRelease     ( bool *id, int i_id_min, int i_id );
 
 typedef struct ps_stream_s
 {
@@ -103,12 +113,12 @@ typedef struct ps_stream_s
 struct sout_mux_sys_t
 {
     /* Which id are unused */
-    vlc_bool_t  stream_id_mpga[16]; /* 0xc0 -> 0xcf */
-    vlc_bool_t  stream_id_mpgv[16]; /* 0xe0 -> 0xef */
-    vlc_bool_t  stream_id_a52[8];   /* 0x80 -> 0x87 <- FIXME I'm not sure */
-    vlc_bool_t  stream_id_spu[32];  /* 0x20 -> 0x3f */
-    vlc_bool_t  stream_id_dts[8];   /* 0x88 -> 0x8f */
-    vlc_bool_t  stream_id_lpcm[16]; /* 0xa0 -> 0xaf */
+    bool  stream_id_mpga[16]; /* 0xc0 -> 0xcf */
+    bool  stream_id_mpgv[16]; /* 0xe0 -> 0xef */
+    bool  stream_id_a52[8];   /* 0x80 -> 0x87 <- FIXME I'm not sure */
+    bool  stream_id_spu[32];  /* 0x20 -> 0x3f */
+    bool  stream_id_dts[8];   /* 0x88 -> 0x8f */
+    bool  stream_id_lpcm[16]; /* 0xa0 -> 0xaf */
 
     int i_audio_bound;
     int i_video_bound;
@@ -116,19 +126,21 @@ struct sout_mux_sys_t
     int i_system_header;
     int i_dts_delay;
     int i_rate_bound; /* units of 50 bytes/second */
-    
+ 
     int64_t i_instant_bitrate;
     int64_t i_instant_size;
     int64_t i_instant_dts;
 
-    vlc_bool_t b_mpeg2;
+    bool b_mpeg2;
+
+    int i_pes_max_size;
 
     int i_psm_version;
     uint32_t crc32_table[256];
 };
 
-static const char *ppsz_sout_options[] = {
-    "dts-delay", NULL
+static const char *const ppsz_sout_options[] = {
+    "dts-delay", "pes-max-size", NULL
 };
 
 /*****************************************************************************
@@ -141,7 +153,7 @@ static int Open( vlc_object_t *p_this )
     vlc_value_t val;
 
     msg_Info( p_mux, "Open" );
-    sout_CfgParse( p_mux, SOUT_CFG_PREFIX, ppsz_sout_options, p_mux->p_cfg );
+    config_ChainParse( p_mux, SOUT_CFG_PREFIX, ppsz_sout_options, p_mux->p_cfg );
 
     p_mux->pf_control   = Control;
     p_mux->pf_addstream = AddStream;
@@ -173,6 +185,9 @@ static int Open( vlc_object_t *p_this )
     var_Get( p_mux, SOUT_CFG_PREFIX "dts-delay", &val );
     p_sys->i_dts_delay = (int64_t)val.i_int * 1000;
 
+    var_Get( p_mux, SOUT_CFG_PREFIX "pes-max-size", &val );
+    p_sys->i_pes_max_size = (int64_t)val.i_int;
+
     /* Initialise CRC32 table */
     if( p_sys->b_mpeg2 )
     {
@@ -217,29 +232,30 @@ static void Close( vlc_object_t * p_this )
  *****************************************************************************/
 static int Control( sout_mux_t *p_mux, int i_query, va_list args )
 {
-    vlc_bool_t *pb_bool;
+    VLC_UNUSED(p_mux);
+    bool *pb_bool;
     char **ppsz;
 
-   switch( i_query )
-   {
-       case MUX_CAN_ADD_STREAM_WHILE_MUXING:
-           pb_bool = (vlc_bool_t*)va_arg( args, vlc_bool_t * );
-           *pb_bool = VLC_TRUE;
-           return VLC_SUCCESS;
+    switch( i_query )
+    {
+        case MUX_CAN_ADD_STREAM_WHILE_MUXING:
+            pb_bool = (bool*)va_arg( args, bool * );
+            *pb_bool = true;
+            return VLC_SUCCESS;
 
-       case MUX_GET_ADD_STREAM_WAIT:
-           pb_bool = (vlc_bool_t*)va_arg( args, vlc_bool_t * );
-           *pb_bool = VLC_FALSE;
-           return VLC_SUCCESS;
+        case MUX_GET_ADD_STREAM_WAIT:
+            pb_bool = (bool*)va_arg( args, bool * );
+            *pb_bool = false;
+            return VLC_SUCCESS;
 
-       case MUX_GET_MIME:
-           ppsz = (char**)va_arg( args, char ** );
-           *ppsz = strdup( "video/mpeg" );
-           return VLC_SUCCESS;
+        case MUX_GET_MIME:
+            ppsz = (char**)va_arg( args, char ** );
+            *ppsz = strdup( "video/mpeg" );
+            return VLC_SUCCESS;
 
         default:
             return VLC_EGENERIC;
-   }
+    }
 }
 
 /*****************************************************************************
@@ -249,7 +265,7 @@ static int AddStream( sout_mux_t *p_mux, sout_input_t *p_input )
 {
     sout_mux_sys_t  *p_sys = p_mux->p_sys;
     ps_stream_t *p_stream;
-    
+ 
 
     msg_Dbg( p_mux, "adding input codec=%4.4s",
              (char*)&p_input->p_fmt->i_codec );
@@ -333,7 +349,7 @@ static int AddStream( sout_mux_t *p_mux, sout_input_t *p_input )
     p_sys->i_instant_bitrate += p_input->p_fmt->i_bitrate + 1000/* overhead */;
 
     /* FIXME -- spec requires  an upper limit rate boundary in the system header;
-       our codecs are VBR; using 2x nominal rate, convert to 50 bytes/sec */ 
+       our codecs are VBR; using 2x nominal rate, convert to 50 bytes/sec */
     p_sys->i_rate_bound += p_input->p_fmt->i_bitrate * 2 / (8 * 50);
     p_sys->i_psm_version++;
 
@@ -505,9 +521,9 @@ static int Mux( sout_mux_t *p_mux )
 
         /* Get and mux a packet */
         p_data = block_FifoGet( p_input->p_fifo );
-        E_( EStoPES )( p_mux->p_sout, &p_data, p_data,
+         EStoPES ( p_mux->p_sout, &p_data, p_data,
                        p_input->p_fmt, p_stream->i_stream_id,
-                       p_sys->b_mpeg2, 0, 0 );
+                       p_sys->b_mpeg2, 0, 0, p_sys->i_pes_max_size );
 
         block_ChainAppend( &p_ps, p_data );
 
@@ -529,16 +545,16 @@ static int Mux( sout_mux_t *p_mux )
 /*****************************************************************************
  *
  *****************************************************************************/
-static void StreamIdInit( vlc_bool_t *id, int i_range )
+static void StreamIdInit( bool *id, int i_range )
 {
     int i;
 
     for( i = 0; i < i_range; i++ )
     {
-        id[i] = VLC_TRUE;
+        id[i] = true;
     }
 }
-static int StreamIdGet( vlc_bool_t *id, int i_id_min, int i_id_max )
+static int StreamIdGet( bool *id, int i_id_min, int i_id_max )
 {
     int i;
 
@@ -546,16 +562,16 @@ static int StreamIdGet( vlc_bool_t *id, int i_id_min, int i_id_max )
     {
         if( id[i] )
         {
-            id[i] = VLC_FALSE;
+            id[i] = false;
 
             return i_id_min + i;
         }
     }
     return -1;
 }
-static void StreamIdRelease( vlc_bool_t *id, int i_id_min, int i_id )
+static void StreamIdRelease( bool *id, int i_id_min, int i_id )
 {
-    id[i_id - i_id_min] = VLC_TRUE;
+    id[i_id - i_id_min] = true;
 }
 
 static void MuxWritePackHeader( sout_mux_t *p_mux, block_t **p_buf,
@@ -595,7 +611,7 @@ static void MuxWritePackHeader( sout_mux_t *p_mux, block_t **p_buf,
 
     if( p_sys->b_mpeg2 )
     {
-        bits_write( &bits, 9,  0 ); // src extention
+        bits_write( &bits, 9,  0 ); // src extension
     }
     bits_write( &bits, 1,  1 );     // marker
 
@@ -620,7 +636,7 @@ static void MuxWriteSystemHeader( sout_mux_t *p_mux, block_t **p_buf,
     sout_mux_sys_t  *p_sys = p_mux->p_sys;
     block_t   *p_hdr;
     bits_buffer_t   bits;
-    vlc_bool_t      b_private;
+    bool      b_private;
     int i_rate_bound;
 
     int             i_nb_private, i_nb_stream;
@@ -653,7 +669,7 @@ static void MuxWriteSystemHeader( sout_mux_t *p_mux, block_t **p_buf,
     bits_write( &bits, 32, 0x01bb );
     bits_write( &bits, 16, 12 - 6 + i_nb_stream * 3 );
     bits_write( &bits, 1,  1 ); // marker bit
-    bits_write( &bits, 22, i_rate_bound); 
+    bits_write( &bits, 22, i_rate_bound);
     bits_write( &bits, 1,  1 ); // marker bit
 
     bits_write( &bits, 6,  p_sys->i_audio_bound );
@@ -669,7 +685,7 @@ static void MuxWriteSystemHeader( sout_mux_t *p_mux, block_t **p_buf,
     bits_write( &bits, 7,  0xff ); // reserved bits
 
     /* stream_id table */
-    for( i = 0, b_private = VLC_FALSE; i < p_mux->i_nb_inputs; i++ )
+    for( i = 0, b_private = false; i < p_mux->i_nb_inputs; i++ )
     {
         sout_input_t *p_input;
         ps_stream_t *p_stream;
@@ -683,7 +699,7 @@ static void MuxWriteSystemHeader( sout_mux_t *p_mux, block_t **p_buf,
             {
                 continue;
             }
-            b_private = VLC_TRUE;
+            b_private = true;
             /* Write stream id */
             bits_write( &bits, 8, 0xbd );
         }
@@ -780,7 +796,7 @@ static void MuxWritePSM( sout_mux_t *p_mux, block_t **p_buf, mtime_t i_dts )
     /* CRC32 */
     {
         uint32_t i_crc = 0xffffffff;
-        for( i = 0; i < p_hdr->i_buffer; i++ )
+        for( i = 0; (size_t)i < p_hdr->i_buffer; i++ )
         i_crc = (i_crc << 8) ^
             p_sys->crc32_table[((i_crc >> 24) ^ p_hdr->p_buffer[i]) & 0xff];
 
@@ -796,15 +812,14 @@ static void MuxWritePSM( sout_mux_t *p_mux, block_t **p_buf, mtime_t i_dts )
 static int MuxGetStream( sout_mux_t *p_mux, int *pi_stream, mtime_t *pi_dts )
 {
     mtime_t i_dts;
-    int     i_stream;
-    int     i;
+    int     i_stream, i;
 
     for( i = 0, i_dts = 0, i_stream = -1; i < p_mux->i_nb_inputs; i++ )
     {
         sout_input_t *p_input = p_mux->pp_inputs[i];
         block_t *p_data;
 
-        if( p_input->p_fifo->i_depth <= 0 )
+        if( block_FifoCount( p_input->p_fifo ) <= 0 )
         {
             if( p_input->p_fmt->i_cat == AUDIO_ES ||
                 p_input->p_fmt->i_cat == VIDEO_ES )
